@@ -304,7 +304,7 @@ def get_query_results(
     """
     Runs query and returns the result as dataframe
 
-    :param return_type: file format to be returned (dict,dataframe,json); default is dataframe
+    :param return_type: file format to be returned (dict,dataframe,json,pyarrow); default is dataframe
     :param service_account_file: relative location of service account file
     :param sql_file: relative location of sql file to read sql from
     :param sql_params: sql parameters dictionary
